deeplake
========

.. currentmodule:: deeplake
.. automodule:: deeplake

.. autofunction:: dataset
.. autofunction:: empty
.. autofunction:: like
.. autofunction:: ingest_classification
.. autofunction:: ingest_coco
.. autofunction:: ingest_yolo
.. autofunction:: ingest_kaggle
.. autofunction:: ingest_dataframe
.. autofunction:: ingest_huggingface
.. autofunction:: load
.. autofunction:: delete
.. autofunction:: rename
.. autofunction:: copy
.. autofunction:: deepcopy
.. autofunction:: connect
.. autofunction:: list
.. autofunction:: exists
.. autofunction:: read
.. autofunction:: link
.. autofunction:: link_tiled
.. autofunction:: tiled
.. autofunction:: compute
.. autofunction:: compose